@@ -66,9 +66,8 @@ _pygtk_style_helper_new(GtkStyle *style, int type, gpointer array)
 						   &PyGtkStyleHelper_Type);
     if (self == NULL)
 	return NULL;
-    pyg_begin_allow_threads;
+
     self->style = g_object_ref(style);
-    pyg_end_allow_threads;
     self->type = type;
     self->array = array;
     return (PyObject *)self;
@@ -77,9 +76,7 @@ _pygtk_style_helper_new(GtkStyle *style, int type, gpointer array)
 static void
 pygtk_style_helper_dealloc(PyGtkStyleHelper_Object *self)
 {
-    pyg_begin_allow_threads;
     g_object_unref(self->style);
-    pyg_end_allow_threads;
     PyObject_DEL(self);
 }
 
@@ -150,12 +147,10 @@ pygtk_style_helper_setitem(PyGtkStyleHelper_Object *self, int pos,
 		PyErr_SetString(PyExc_TypeError, "can only assign a GdkGC");
 		return -1;
 	    }
-	    pyg_begin_allow_threads;
 	    if (array[pos]) {
 		g_object_unref(array[pos]);
 	    }
 	    array[pos] = GDK_GC(g_object_ref(pygobject_get(value)));
-	    pyg_end_allow_threads;
 	    return 0;
 	}
     case STYLE_PIXMAP_ARRAY:
@@ -167,7 +162,6 @@ pygtk_style_helper_setitem(PyGtkStyleHelper_Object *self, int pos,
 				"can only assign a GdkPixmap or None");
 		return -1;
 	    }
-	    pyg_begin_allow_threads;
 	    if (array[pos]) {
 		g_object_unref(array[pos]);
 	    }
@@ -175,7 +169,6 @@ pygtk_style_helper_setitem(PyGtkStyleHelper_Object *self, int pos,
 		array[pos] = GDK_PIXMAP(g_object_ref(pygobject_get(value)));
 	    else
 		array[pos] = NULL;
-	    pyg_end_allow_threads;
 	    return 0;
 	}
     }
@@ -409,7 +402,7 @@ PyGdkWindow_PropertyGet(PyGdkWindow_Object *self, PyObject *args)
     if (Pyerr_Occurred())
 	return NULL;
 	
-    if (gdk_property_get(self->obj, property, type, 0, 9999,
+    if (gdk_property_get(self->obj, property, type, 0, G_MAXLONG,
 			 pdelete, &atype, &aformat, &alength, &data)) {
 	/* success */
 	PyObject *pdata = NULL;
@@ -856,9 +849,7 @@ _pygtk_tree_model_row_new(GtkTreeModel *model, GtkTreeIter *iter)
 static void
 pygtk_tree_model_row_dealloc(PyGtkTreeModelRow *self)
 {
-    pyg_begin_allow_threads;
     g_object_unref(self->model);
-    pyg_end_allow_threads;
     PyObject_DEL(self);
 }
 
@@ -1066,9 +1057,7 @@ _pygtk_tree_model_row_iter_new(GtkTreeModel *model, GtkTreeIter *parent_iter)
 static void
 pygtk_tree_model_row_iter_dealloc(PyGtkTreeModelRowIter *self)
 {
-    pyg_begin_allow_threads;
     g_object_unref(self->model);
-    pyg_end_allow_threads;
     PyObject_DEL(self);
 }
 
